@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2019 The plumed team
+   Copyright (c) 2011-2021 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -22,11 +22,6 @@
 #include "Colvar.h"
 #include "ActionRegister.h"
 
-#include <string>
-#include <cmath>
-
-using namespace std;
-
 namespace PLMD {
 namespace colvar {
 
@@ -51,7 +46,7 @@ class Volume : public Colvar {
 public:
   explicit Volume(const ActionOptions&);
 // active methods:
-  virtual void calculate();
+  void calculate() override;
 /// Register all the keywords for this action
   static void registerKeywords( Keywords& keys );
 };
